@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2020  Błażej Szczygieł
+    Copyright (C) 2010-2021  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -571,7 +571,8 @@ bool D3D11VAVulkan::createImageInterop(const shared_ptr<Device> &device, Frame &
         device,
         imageSize,
         m_formatVk,
-        m_linearImage
+        m_linearImage,
+        m_externalMemoryHandleType
     );
 
     if (m_zeroCopy)
