@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2020  Błażej Szczygieł
+    Copyright (C) 2010-2021  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -70,7 +70,7 @@ ModuleSettingsWidget::ModuleSettingsWidget(Module &module) :
 
     QFormLayout *layout = new QFormLayout(this);
     layout->addRow(enabledB);
-    layout->addRow(tr("Delay") + ": ", delayB);
+    layout->addRow(tr("Maximum latency") + ": ", delayB);
 }
 
 void ModuleSettingsWidget::saveSettings()
